Class: RougePicat::Picat
- Inherits:
-
Rouge::RegexLexer
- Object
- Rouge::RegexLexer
- RougePicat::Picat
- Defined in:
- lib/rouge-picat.rb
Class Method Summary collapse
Class Method Details
.builtins ⇒ Object
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/rouge-picat.rb', line 41 def self.builtins @builtins ||= Set.new %w( append write writeln print println member length solve solve_all new_array new_map new_set min max sum prod floor ceiling round abs sqrt sin cos tan log exp open close printf get_heap_map get_global_map get_table_map instance final action solve ) end |
.keywords ⇒ Object
31 32 33 34 35 36 37 38 39 |
# File 'lib/rouge-picat.rb', line 31 def self.keywords @keywords ||= Set.new %w( module import private table index if else elseif end foreach while do not fail true false catch try in repeat once var throw ) end |